@@ -2,6 +2,7 @@
 from __future__ import print_function
 
 import io
+import logging
 import os
 import platform
 import sys
@@ -177,3 +178,67 @@ def test_bufsize():
     with wurlitzer.pipes(bufsize=bufsize) as (stdout, stderr):
         assert fcntl(sys.__stdout__, wurlitzer.F_GETPIPE_SZ) == bufsize
         assert fcntl(sys.__stderr__, wurlitzer.F_GETPIPE_SZ) == bufsize
+
+
+def test_log_pipes(caplog):
+    with caplog.at_level(logging.INFO), wurlitzer.pipes(
+        logging.getLogger("wurlitzer.stdout"), logging.getLogger("wurlitzer.stderr")
+    ):
+        printf("some stdout")
+        printf_err("some stderr")
+
+    stdout_logs = []
+    stderr_logs = []
+    for t in caplog.record_tuples:
+        if "stdout" in t[0]:
+            stdout_logs.append(t)
+        else:
+            stderr_logs.append(t)
+
+    assert stdout_logs == [
+        ("wurlitzer.stdout", logging.INFO, "some stdout"),
+    ]
+    assert stderr_logs == [
+        ("wurlitzer.stderr", logging.ERROR, "some stderr"),
+    ]
+
+    for record in caplog.records:
+        # check 'stream' extra
+        assert record.stream
+        assert record.name == "wurlitzer." + record.stream
+
+
+def test_two_file_pipes(tmpdir):
+
+    test_stdout = tmpdir / "stdout.txt"
+    test_stderr = tmpdir / "stderr.txt"
+
+    with test_stdout.open("ab") as stdout_f, test_stderr.open("ab") as stderr_f:
+        w = Wurlitzer(stdout_f, stderr_f)
+        with w:
+            assert w.thread is None
+            printf("some stdout")
+            printf_err("some stderr")
+
+    with test_stdout.open() as f:
+        assert f.read() == "some stdout\n"
+    with test_stderr.open() as f:
+        assert f.read() == "some stderr\n"
+
+
+def test_one_file_pipe(tmpdir):
+
+    test_stdout = tmpdir / "stdout.txt"
+
+    with test_stdout.open("ab") as stdout_f:
+        stderr = io.StringIO()
+        w = Wurlitzer(stdout_f, stderr)
+        with w as (stdout, stderr):
+            assert w.thread is not None
+            printf("some stdout")
+            printf_err("some stderr")
+        assert not w.thread.is_alive()
+
+    with test_stdout.open() as f:
+        assert f.read() == "some stdout\n"
+    assert stderr.getvalue() == "some stderr\n"
